==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/efd/layout_16.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2021 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2021, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import layout_15
from layout_15 import bloco_1 as efd_bloco_1
from pythonsped.utils import TrackedAttributesClass

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2022'
_codigo_ = '016'  # layout_16
_versao_ = '115'


class bloco_0(layout_15.bloco_0):
    pass


class bloco_1(efd_bloco_1):

    class registro_1601(TrackedAttributesClass):
        """
        OPERACOESS COM INSTRUMENTOS DE PAGAMENTO ELETRONICOS (VALIDO A PARTIR DE 01/01/2022)
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1601, self).__init__()
            self.REG = '1601'
            self.nivel_h = 2
            self.pai = '1001'
            self.ocorrencia = 'N'
            self.COD_PART_IP = ''
            self.COD_PART_IT = ''
            self.TOT_VS = ''
            self.TOT_ISS = ''
            self.TOT_OUTROS = ''
            self.fieldnames = ('REG', 'COD_PART_IP', 'COD_PART_IT', 'TOT_VS', 'TOT_ISS',
                               'TOT_OUTROS')
            self.formato = self.get_formato()


class bloco_c(layout_15.bloco_c):

    class registro_C500(layout_15.bloco_c.registro_C500):
        def __init__(self):
            super(bloco_c.registro_C500, self).__init__()
            self.COD_MOD_DOC_REF = ''
            self.HASH_DOC_REF = ''
            self.SER_DOC_REF = ''
            self.NUM_DOC_REF = ''
            self.MES_DOC_REF = ''
            self.ENER_INJET = ''
            self.OUTRAS_DED = ''
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'COD_CONS', 'NUM_DOC', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'VL_DESC', 'VL_FORN', 'VL_SERV_NT', 'VL_TERC', 'VL_DA', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'COD_INF', 'VL_PIS',
                               'VL_COFINS', 'TP_LIGACAO', 'COD_GRUPO_TENSAO', 'CHV_DOCe',
                               'FIN_DOCe', 'CHV_DOCe_REF', 'IND_DEST', 'COD_MUN_DEST', 'COD_CTA',
                               'COD_MOD_DOC_REF', 'HASH_DOC_REF', 'SER_DOC_REF', 'NUM_DOC_REF',
                               'MES_DOC_REF', 'ENER_INJET', 'OUTRAS_DED')
            self.formato = self.get_formato()


class bloco_e(layout_15.bloco_e):
    pass


class bloco_g(layout_15.bloco_g):
    pass

==> sped-3.0.4.tar.gz: sped-3.0.4/pythonsped/efd/layout_16.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2021 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2021, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from . import layout_15
from . layout_15 import bloco_1 as efd_bloco_1
from ..utils import TrackedAttributesClass

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2022'
_codigo_ = '016'  # layout_16
_versao_ = '115'


class bloco_0(layout_15.bloco_0):
    pass


class bloco_1(efd_bloco_1):

    class registro_1601(TrackedAttributesClass):
        """
        OPERACOESS COM INSTRUMENTOS DE PAGAMENTO ELETRONICOS (VALIDO A PARTIR DE 01/01/2022)
        """
        _order = []

        def __init__(self):
            super(bloco_1.registro_1601, self).__init__()
            self.REG = '1601'
            self.nivel_h = 2
            self.pai = '1001'
            self.ocorrencia = 'N'
            self.COD_PART_IP = ''
            self.COD_PART_IT = ''
            self.TOT_VS = ''
            self.TOT_ISS = ''
            self.TOT_OUTROS = ''
            self.fieldnames = ('REG', 'COD_PART_IP', 'COD_PART_IT', 'TOT_VS', 'TOT_ISS',
                               'TOT_OUTROS')
            self.formato = self.get_formato()


class bloco_c(layout_15.bloco_c):

    class registro_C500(layout_15.bloco_c.registro_C500):
        def __init__(self):
            super(bloco_c.registro_C500, self).__init__()
            self.COD_MOD_DOC_REF = ''
            self.HASH_DOC_REF = ''
            self.SER_DOC_REF = ''
            self.NUM_DOC_REF = ''
            self.MES_DOC_REF = ''
            self.ENER_INJET = ''
            self.OUTRAS_DED = ''
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'COD_CONS', 'NUM_DOC', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'VL_DESC', 'VL_FORN', 'VL_SERV_NT', 'VL_TERC', 'VL_DA', 'VL_BC_ICMS',
                               'VL_ICMS', 'VL_BC_ICMS_ST', 'VL_ICMS_ST', 'COD_INF', 'VL_PIS',
                               'VL_COFINS', 'TP_LIGACAO', 'COD_GRUPO_TENSAO', 'CHV_DOCe',
                               'FIN_DOCe', 'CHV_DOCe_REF', 'IND_DEST', 'COD_MUN_DEST', 'COD_CTA',
                               'COD_MOD_DOC_REF', 'HASH_DOC_REF', 'SER_DOC_REF', 'NUM_DOC_REF',
                               'MES_DOC_REF', 'ENER_INJET', 'OUTRAS_DED')
            self.formato = self.get_formato()


class bloco_e(layout_15.bloco_e):
    pass


class bloco_g(layout_15.bloco_g):
    pass
